@@ -110,6 +110,10 @@ typedef enum
 	AMMO_SLUGS
 } ammo_t;
 
+/* Maximum debris / gibs per frame */
+#define MAX_GIBS 20
+#define MAX_DEBRIS 20
+
 /* deadflag */
 #define DEAD_NO 0
 #define DEAD_DYING 1
@@ -446,8 +450,8 @@ extern spawn_temp_t st;
 extern int sm_meat_index;
 extern int snd_fry;
 
+extern int debristhisframe;
 extern int gibsthisframe;
-extern int lastgibframe;
 
 
 /* means of death */
